API reference
=============

This section aims to give an overview of all classes, functions and methods in the metasyn package. 

.. toctree::
   :maxdepth: 1

   metasyn.distribution
   metasyn.demo
   metaframe
   varspec
   developer_reference

